==> alg-feature-1.37.18-20200729.024153-1-sources.jar: cn/com/duiba/nezha/alg/feature/vo/RoutineActFeature.java <==
package cn.com.duiba.nezha.alg.feature.vo;

public class RoutineActFeature {

    private String routineActId;
    private Double routineActHistClick;    //f301002 常规活动历史点击率
    private Double routineActWeekClick;    //f301003 常规活动一周点击率
    private Double routineActHistOrder;  //f301004 常规活动历史转化率
    private Double routineActWeekOrder; //f301005 常规活动一周转化率
    private String routineActTradeVisitTime;   //f301006 行业标签（媒体）访问次数
    private String routineActTradeClickTime;    //f301007 行业标签（媒体）参与次数
    private String routineActActType;   //f301008 活动类型

    public String getRoutineActId() {
        return routineActId;
    }

    public void setRoutineActId(String routineActId) {
        this.routineActId = routineActId;
    }

    public Double getRoutineActHistClick() {
        return routineActHistClick;
    }

    public void setRoutineActHistClick(Double routineActHistClick) {
        this.routineActHistClick = routineActHistClick;
    }

    public Double getRoutineActWeekClick() {
        return routineActWeekClick;
    }

    public void setRoutineActWeekClick(Double routineActWeekClick) {
        this.routineActWeekClick = routineActWeekClick;
    }

    public Double getRoutineActHistOrder() {
        return routineActHistOrder;
    }

    public void setRoutineActHistOrder(Double routineActHistOrder) {
        this.routineActHistOrder = routineActHistOrder;
    }

    public Double getRoutineActWeekOrder() {
        return routineActWeekOrder;
    }

    public void setRoutineActWeekOrder(Double routineActWeekOrder) {
        this.routineActWeekOrder = routineActWeekOrder;
    }

    public String getRoutineActTradeVisitTime() {
        return routineActTradeVisitTime;
    }

    public void setRoutineActTradeVisitTime(String routineActTradeVisitTime) {
        this.routineActTradeVisitTime = routineActTradeVisitTime;
    }

    public String getRoutineActTradeClickTime() {
        return routineActTradeClickTime;
    }

    public void setRoutineActTradeClickTime(String routineActTradeClickTime) {
        this.routineActTradeClickTime = routineActTradeClickTime;
    }

    public String getRoutineActActType() {
        return routineActActType;
    }

    public void setRoutineActActType(String routineActActType) {
        this.routineActActType = routineActActType;
    }

}

==> alg-feature-2.23.72-sources.jar: cn/com/duiba/nezha/alg/feature/vo/RoutineActFeature.java <==
package cn.com.duiba.nezha.alg.feature.vo;

import lombok.Data;

import java.io.Serializable;

@Data
public class RoutineActFeature implements Serializable {

    private String routineActId;
    private Double routineActHistClick;    //f301002 常规活动历史点击率
    private Double routineActWeekClick;    //f301003 常规活动一周点击率
    private Double routineActHistOrder;  //f301004 常规活动历史转化率
    private Double routineActWeekOrder; //f301005 常规活动一周转化率
    private String routineActTradeVisitTime;   //f301006 行业标签（媒体）访问次数
    private String routineActTradeClickTime;    //f301007 行业标签（媒体）参与次数
    private String routineActActType;   //f301008 活动类型
    private Double routineActHistConsumer; // 历史每UV消耗
    private Double routineActWeekConsumer; // 一周每UV消耗
    private Double routineActDayConsumer; // 当日每UV消耗

    public String getRoutineActId() {
        return routineActId;
    }

    public void setRoutineActId(String routineActId) {
        this.routineActId = routineActId;
    }

    public Double getRoutineActHistClick() {
        return routineActHistClick;
    }

    public void setRoutineActHistClick(Double routineActHistClick) {
        this.routineActHistClick = routineActHistClick;
    }

    public Double getRoutineActWeekClick() {
        return routineActWeekClick;
    }

    public void setRoutineActWeekClick(Double routineActWeekClick) {
        this.routineActWeekClick = routineActWeekClick;
    }

    public Double getRoutineActHistOrder() {
        return routineActHistOrder;
    }

    public void setRoutineActHistOrder(Double routineActHistOrder) {
        this.routineActHistOrder = routineActHistOrder;
    }

    public Double getRoutineActWeekOrder() {
        return routineActWeekOrder;
    }

    public void setRoutineActWeekOrder(Double routineActWeekOrder) {
        this.routineActWeekOrder = routineActWeekOrder;
    }

    public String getRoutineActTradeVisitTime() {
        return routineActTradeVisitTime;
    }

    public void setRoutineActTradeVisitTime(String routineActTradeVisitTime) {
        this.routineActTradeVisitTime = routineActTradeVisitTime;
    }

    public String getRoutineActTradeClickTime() {
        return routineActTradeClickTime;
    }

    public void setRoutineActTradeClickTime(String routineActTradeClickTime) {
        this.routineActTradeClickTime = routineActTradeClickTime;
    }

    public String getRoutineActActType() {
        return routineActActType;
    }

    public void setRoutineActActType(String routineActActType) {
        this.routineActActType = routineActActType;
    }

}
